MEM-enriched cluster labels
mem_labels.RdGenerates descriptive labels for each cluster that include measured features specifically enriched on the population based on MEM scores, following the cytoMEM format. Markers are ranked by absolute MEM score and separated into positively and negatively enriched groups.
Arguments
- x
The return value of
altmem()orcytoMEM::MEM().- min_label_score
Minimum absolute MEM score for a marker to be included in the label. Defaults to
1.- max_label_markers
Maximum number of markers to include per direction (positive and negative) in each label. Defaults to
5.- show_label_scores
Whether to include MEM scores alongside marker names. Defaults to
TRUE.